==> ixnetwork_restpy-0.1.27-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/capture/currentpacket/stack/field/field.py <==
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Field(Base):
	"""The Field class encapsulates a system managed field node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Field property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'field'

	def __init__(self, parent):
		super(Field, self).__init__(parent)

	@property
	def DisplayName(self):
		"""Refers to the name of the field.

		Returns:
			str
		"""
		return self._get_attribute('displayName')

	@property
	def FieldValue(self):
		"""Refers to the value displayed in the field.

		Returns:
			str
		"""
		return self._get_attribute('fieldValue')

	def find(self, DisplayName=None, FieldValue=None):
		"""Finds and retrieves field data from the server.

		All named parameters support regex and can be used to selectively retrieve field data from the server.
		By default the find method takes no parameters and will retrieve all field data from the server.

		Args:
			DisplayName (str): Refers to the name of the field.
			FieldValue (str): Refers to the value displayed in the field.

		Returns:
			self: This instance with found field data from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of field data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the field data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

==> ixnetwork_restpy-0.1.34-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/capture/currentpacket/stack/field/field.py <==
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Field(Base):
	"""The Field class encapsulates a system managed field node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Field property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'field'

	def __init__(self, parent):
		super(Field, self).__init__(parent)

	@property
	def DisplayName(self):
		"""Refers to the name of the field.

		Returns:
			str
		"""
		return self._get_attribute('displayName')

	@property
	def FieldValue(self):
		"""Refers to the value displayed in the field.

		Returns:
			str
		"""
		return self._get_attribute('fieldValue')

	def find(self, DisplayName=None, FieldValue=None):
		"""Finds and retrieves field data from the server.

		All named parameters support regex and can be used to selectively retrieve field data from the server.
		By default the find method takes no parameters and will retrieve all field data from the server.

		Args:
			DisplayName (str): Refers to the name of the field.
			FieldValue (str): Refers to the value displayed in the field.

		Returns:
			self: This instance with matching field data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of field data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the field data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
